source $XCeptLibDir/bindings.tcl
#source $XCeptLibDir/FSBox.tcl
source $XCeptLibDir/inputBox.tcl
source $XCeptLibDir/messageBox.tcl

set XCeptUsrDir ""
set XCeptSourceSystemRessource 1
set XCeptSourceUserRessource 1

# ... setup Tk defaults ...
proc XCeptSetTkDefaults {} {
    global tk_strictMotif
    
    option add *background lightgrey
    option add *foreground black
    option add *activeBackground grey70
    option add *activeForeground black
    #option add *Scrollbar.foreground grey60
    #option add *Scrollbar.activeForeground grey50
    option add *Scrollbar.width 11
    option add *Scrollbar.borderWidth 1
    option add *Entry.background white
    option add *Listbox.background white
    #option add *selectBackground maroon
    option add *selectBackground black
    option add *selectForeground white
    
    option add *font "-adobe-new century schoolbook-medium-r-*-*-14-*-*-*-*-*-*-*"
#    option add *font "-dt-interface system-medium-r-*-s serif-*-*-*-*-*-*-*-*"
    
    option add *Menubutton.foreground white
    option add *Menubutton.background "#6b7f949fb200"
    option add *Menu.foreground white
    option add *Menu.background "#6b7f949fb200"
    
    set tk_strictMotif 1
}

proc XCeptConnectDisconnect {XCeptHostname XCeptPortNumber} {
    global XCeptStatus

    # ... are we disconnected? ...
    switch -glob $XCeptStatus {
	DISCONNECTED* {
	    # ... energize! ...
	    XCeptConnect $XCeptHostname $XCeptPortNumber
	}
	default {
	    # ... hmm, seem to be connected ...
	    XCeptDisconnect
	}
    }
}

# ... create and show XCept control window ...
proc XCeptShowWindow {}  {
    global XCeptStatus XCeptHostname XCeptPortNumber 
    global XCeptSysDir XCeptUsrDir 
    global env

    XCeptSetTkDefaults
    #XCeptSetTkBindings

    wm title . "XCept Control Panel"

    # ... declare main frame containing the others ...
    frame .mainframe
    pack .mainframe

    # ... menuframe contains the menu ...
    #frame .menuframe -bd 2 -relief groove
    frame .menuframe -bd 2 -relief raised -background "#6b7f949fb200"
    # ... buttonframe contains the button rows ...
    frame .buttonframe -bd 2
    # ... the entryframe hosts the server and the port entry fields ...
    frame .entryframe -bd 2 -relief groove
    frame .statusframe -bd 2 -relief groove

    # ... assemble the whole lot:
    #     .menuframe
    #     .buttonframe
    #     .entryframe
    #     .statusframe
    pack .menuframe -in .mainframe -side top -fill x
    pack .buttonframe .entryframe .statusframe \
	    -in .mainframe -side top -fill x -pady 5 -padx 3

    # ... STATUS Labels ...
    # ... labels to indicate the current status of XCept ...
    #     .status2label tracks XCeptStatus
    label .status1label -text Status: 
    label .status2label -textvariable XCeptStatus -fg maroon
    pack .status1label .status2label -in .statusframe -side left -padx 5 


    # ... ENTRY Fields ...
    # ... the entry fields let the user specify server and port ...
    # ... the server entry first ...
    frame .entryframe.left
    frame .entryframe.right

    label .serverlabel -text Server:
    # ... .serverentry tracks and sets the XCeptHostname variable ...
    entry .serverentry -width 35 -textvariable XCeptHostname -relief sunken -background white
    pack .serverlabel  -in .entryframe.left -side top -padx 5 -anchor w
    pack .serverentry -in .entryframe.right -side top -padx 5 -anchor w
    # ... and then the port entry ...
    label .portlabel -text Port:
    # ... .portentry sets the XCeptPortNumber variable ...
    entry .portentry -width 6 -textvariable XCeptPortNumber -relief sunken -background white
    pack .portlabel -in .entryframe.left -side top -padx 5 -anchor w
    pack .portentry -in .entryframe.right -side top -padx 5 -anchor w

    pack .entryframe.left .entryframe.right -in .entryframe -side left -pady 2 -anchor w


    # ... BUTTON descriptions ...
    # ... describe the XCept buttons now ...
    # ... the connect, quit, tia, reveal, chsize buttons ...
    button .quitbutton -bitmap XCeptBitmapQuit -command {exit 0}
    button .connectbutton -bitmap XCeptBitmapConnect \
	    -command {XCeptConnectDisconnect $XCeptHostname $XCeptPortNumber}
    button .tiabutton -bitmap XCeptBitmapTIA -command XCeptTIA
    button .revealbutton -bitmap XCeptBitmapReveal -command XCeptReveal
    button .chsizebutton -bitmap XCeptBitmapChsize \
	-command XCeptChsizeCEPTWin
    label .immdLogo -bitmap XCeptBitmapIMMD4

    # ... and now for another assembly ...
    pack .connectbutton .tiabutton \
	    .revealbutton .chsizebutton .quitbutton \
	    -in .buttonframe -side left
    pack .immdLogo -in .buttonframe -side left -expand 1 -anchor e
    
    # ... MENU: File ...
    menubutton .filembutton -text File -menu .filembutton.menu
    menu .filembutton.menu
    .filembutton.menu add command -label "About XCept" \
	    -command XCeptAboutXCept
    .filembutton.menu add command -label "Copyright" \
	    -command XCeptCopyright
    .filembutton.menu add separator
    .filembutton.menu add command -label "Save page as text" \
	    -command {
	#set fsBox(pattern) *
	#set name [FSBox "Select name for text file"]
	set name [tk_getOpenFile -parent . -title "Select name for text file"]
	if {$name != ""} {
	    XCeptSaveASCII $name
	}
    }
    .filembutton.menu add command -label "Save page as PPM" \
	    -command {
	#set fsBox(pattern) *
	#set name [FSBox "Select name for PPM file"]
	set name [tk_getSaveFile -parent . -title "Select name for PPM file"]
	if {$name != ""} {
	    XCeptSavePPM $name}
    }
    .filembutton.menu add separator
    .filembutton.menu add command -label Quit -command {exit 0}

    # ... MENU: Script ...
    menubutton .scriptmbutton -text Script -menu .scriptmbutton.menu
    menu .scriptmbutton.menu
    .scriptmbutton.menu add command -label "source TCL script" \
	    -command {
	#set fsBox(pattern) *.xcept
	#set name [FSBox "Select script to execute"]
	set name [tk_getOpenFile -parent . -title "Select script to execute"]
	if {$name != ""} {
	    source "$name"
	}
    }
    .scriptmbutton.menu add command -label "enter TCL code" \
	    -command XCeptExecCode
    .scriptmbutton.menu add separator

    # ... while we're at it, take a first look at the scripts directories ...
    # ... first in the XCEPTSCRIPTS directories ...
    if {[info exists env(XCEPTSCRIPTS)] || $XCeptUsrDir != ""} {
	if {$XCeptUsrDir != ""} {
	    XCeptScriptsAddPathList .scriptmbutton.menu $XCeptUsrDir
	}
	if {[info exists env(XCEPTSCRIPTS)]} {
	    XCeptScriptsAddPathList .scriptmbutton.menu $env(XCEPTSCRIPTS)
	}
    }
    # ... then in the scriptdir directory (as set during compilation) ...
    XCeptScriptsAddPathList .scriptmbutton.menu $XCeptSysDir
      
    # ... MENU: Session ...
    menubutton .sessionmbutton -text Session -menu .sessionmbutton.menu
    menu .sessionmbutton.menu
    .sessionmbutton.menu add command -label "start recording" \
	    -command {
	#set fsBox(pattern) *
	#set name [FSBox "Select name for session log file"]
	set name [tk_getSaveFile -parent . -title "Select name for session log file"]
	if {$name != ""} "XCeptStartRecord $name"
    }
    .sessionmbutton.menu add command -label "stop  recording" \
	    -command XCeptStopRecord
    .sessionmbutton.menu add command -label "start playback" \
	    -command {
	#set fsBox(pattern) *
	#set name [FSBox "Select name for PLAYBACK file"]
	set name [tk_getOpenFile -parent . -title "Select name for PLAYBACK file"]
	if {$name != ""} "XCeptStartPlayback $name"
    }
    .sessionmbutton.menu add command -label "stop  playback" \
	    -command XCeptStopPlayback
    .sessionmbutton.menu add separator
    .sessionmbutton.menu add command -label "start debug logging" \
	    -command {
	#set fsBox(pattern) *
	#set name [FSBox "Select name for debug log file"]
	set name [tk_getSaveFile -parent . -title "Select name for debug log file"]
	if {$name != ""} "XCeptStartDebugLog $name"
    }
    .sessionmbutton.menu add command -label "stop  debug logging" \
	    -command XCeptStopDebugLog
    
    # ... MENU Assembly ...
    pack .filembutton .scriptmbutton .sessionmbutton \
	    -in .menuframe -side left -padx 7

    
#    # ... BINDINGS ...
#    bind all <Any-KeyPress> {
#	if {"%A" != ""} {
#	    XCeptKeyPress %N %s %A
#	}
#    }
#    bind Entry <Return> {focus .}


    # ... TRACEs? ...
    trace variable XCeptStatus w XCeptStatusTrace

    # ... and manually invoke XCeptStatusTrace to initialize the buttons ...
    XCeptStatusTrace
}


# ... process : separated script dir path ...
proc XCeptScriptsAddPathList {menuCmd pathList} {
    foreach dirName [split $pathList :] {
	foreach filename [glob -nocomplain $dirName/*.xcept] {
	    set cmd "source \"$filename\""
	    $menuCmd add command \
		    -label "[file rootname [file tail $filename]]" \
		    -command $cmd
	}
    }
}


# ... trace the XCeptStatusTrace variable ...
proc XCeptStatusTrace {{variableName ""} {elementName ""} {operation ""}} {
    global XCeptStatus XCeptConnectStatus XCeptPlaybackStatus 
    global XCeptTIAStatus XCeptRevealStatus
    global XCeptRecordStatus XCeptDebugStatus

    # 'catch' the following statements because Tk may not be active
    # (and therefore no widgets installed) when the trace triggers

    catch {
	# ... only do this if we are connected or doing a playback ...
	if {$XCeptConnectStatus == 1 || $XCeptPlaybackStatus == 1} {
	    .connectbutton configure -bitmap XCeptBitmapDisconnect
	    .sessionmbutton.menu entryconfigure *start*play* -state disabled

	    if {$XCeptPlaybackStatus == 1} {
		.connectbutton configure -state disabled
		.sessionmbutton.menu entryconfigure *stop*play* -state normal
	    }

	    if {$XCeptConnectStatus == 1} {
		.connectbutton configure -state normal
		.sessionmbutton.menu entryconfigure *stop*play* -state disabled
	    }
	} else {
	    .connectbutton configure -state normal -bitmap XCeptBitmapConnect
	    .sessionmbutton.menu entryconfigure *start*play* -state normal 
	    .sessionmbutton.menu entryconfigure *stop*play* -state disabled
	}

	if {$XCeptTIAStatus == 1} {
	    .revealbutton configure -state disabled
	} else {
	    .revealbutton configure -state normal
	}

	if {$XCeptRecordStatus == 1} {
	    .sessionmbutton.menu entryconfigure *start*rec* -state disabled 
	    .sessionmbutton.menu entryconfigure *stop*rec* -state normal
	} else {
	    .sessionmbutton.menu entryconfigure *start*rec* -state normal 
	    .sessionmbutton.menu entryconfigure *stop*rec* -state disabled
	}

	if {$XCeptDebugStatus == 1} {
	    .sessionmbutton.menu entryconfigure *start*debug* -state disabled
	    .sessionmbutton.menu entryconfigure *stop*debug* -state normal
	} else {
	    .sessionmbutton.menu entryconfigure *start*debug* -state normal
	    .sessionmbutton.menu entryconfigure *stop*debug* -state disabled 
	}
   }
}


# ... parse XCept options ...
proc XCeptParseOptions {} {
    global argc argv 
    global XCeptHostname XCeptPortNumber 
    global XCeptSysDir XCeptUsrDir XCeptLibDir
    global env XCeptPlaybackFilename XCeptHaveColor 
    global XCeptScriptFilename XCeptScriptParList
    global XCeptWantWindow XCeptWantConnect XCeptWantSize
    global XCeptSourceSystemRessource
    global XCeptSourceUserRessource

    set XCeptUsrDir ""
    set XCeptPlaybackFilename ""
    set XCeptScriptFilename ""
    set XCeptScriptParList [list]
    set XCeptHaveColor 1
    set XCeptWantSize 1
    set XCeptWantWindow 1
    set XCeptWantConnect 0

    if {[info exists env(XCEPTHOST)]} {
	set XCeptHostname $env(XCEPTHOST)
    }

    for {set i 1} {$i<$argc} {incr i} {
	if { [string index $argv($i) 0] != "-" } XCeptUsage

	# ... special case: check for -display ...
	if {[string match "-display" $argv($i)]} {
	    incr i
	    set env(DISPLAY) $argv($i)
	    continue
	}
	if { [string index $argv($i) 2] != "\000" } XCeptUsage

	switch [string index $argv($i) 1] {
	    # ... -? ...
	    ? {
		XCeptUsage
	    }
	    # ... -h ...
	    h {
		if {$i >= $argc-1} XCeptUsage
		incr i
		set XCeptHostname $argv($i)
	    }

	    # ... -i ...
	    i {
		set XCeptSourceUserRessource 0
	    }

	    # ... -I ...
	    I {
		set XCeptSourceSystemRessource 0
	    }

	    # ... -p ...
	    p {
		if {$i >= $argc-1} XCeptUsage
		incr i
		set XCeptPortNumber $argv($i)
	    }

	    # ... -r ...
	    r {
		if {$i >= $argc-1} XCeptUsage
		incr i
		set XCeptPlaybackFilename $argv($i)
	    }

	    # ... -S ...
	    S {
		if {$i >= $argc-1} XCeptUsage
		incr i
		set XCeptUsrDir $argv($i)
	    }

	    # ... -s ...
	    s {
		if {$i >= $argc-1} XCeptUsage
		incr i
		set XCeptScriptFilename $argv($i)

		for {incr i} {$i<$argc} {incr i} {
		    set XCeptScriptParList [lappend \
			    XCeptScriptParList $argv($i)]
		}
	    }

	    # ... -t ...
	    t {
		if {$i >= $argc-1} XCeptUsage
		incr i
		XCeptStartDebugLog $argv($i)
	    }

	    # ... -l ...
	    l {
		if {$i >= $argc-1} XCeptUsage
		incr i
		XCeptStartRecord $argv($i)
	    }

	    # ... -c ...
	    c { set XCeptWantConnect 1 }

	    # ... -x ...
	    x { set XCeptWantWindow 0 }

	    # ... -2 ...
	    2 { set XCeptWantSize 2 }
	    
	    # ... -m ...
	    m { set XCeptHaveColor 0 }

	    # ... default: ...
	    default { XCeptUsage }
	}
    }

    if { $XCeptWantWindow == 0 && $XCeptScriptFilename == "" } {
	puts stderr "\nXCept: you can't use xcept without X11 AND\
		NO script running !!\n"
	exit 1
    }
}


# ... now for a word to our users ...
proc XCeptUsage {} {
    global XCeptVersion argc argv XCeptHostname XCeptPortNumber

    puts stderr "\n$XCeptVersion\n"
    puts stderr "usage: $argv(0) \[options\]\n"
    puts stderr "valid options are:"
    puts stderr "\t-?        usage"
    puts stderr "\t-h host   connect to ceptd@'host' ($XCeptHostname)"
    puts stderr "\t-p port   use socket port 'port' ($XCeptPortNumber)"
    puts stderr "\t-l file   log session data to 'file'"
    puts stderr "\t-t file   log debug text to 'file'"
    puts stderr "\t-r file   replay session from 'file' on startup"
    puts stderr "\t-c        connect to server on startup"
    puts stderr "\t-x        don't use window system on startup"
    puts stderr "\t-2        display each pixel as 2x2 pixels"
    puts stderr "\t-m        force monochrome display"
    puts stderr "\t-S pathes colon separated list of script directories"
    puts stderr "\t-i        do not source ~/.xceptrc on startup"
    puts stderr "\t-I        do not source system-wide resource file on startup"
    puts stderr "\t-s file   execute script 'file' on startup"
    puts stderr "\t          (last option followed by parameters)"
    puts stderr ""
    exit 1
}

# ... what this is all about? ...
proc XCeptAboutXCept {{w .about}} {
    global XCeptVersion XCeptVersionComment

    catch {destroy $w}
    toplevel $w
    wm title $w "About XCept"

    frame $w.headframe -bd 1 -relief raised
    frame $w.topframe -bd 1 -relief raised
    frame $w.botframe -bd 1 -relief raised
    pack $w.headframe $w.topframe $w.botframe -side top -fill both

    message $w.headframe.msg1 -justify center -aspect 1000 \
	    -font "-adobe-new century schoolbook-bold-r-*-*-17-*-*-*-*-*-iso8859-1" \
	    -text "$XCeptVersion"
    message $w.headframe.msg2 -justify center -aspect 3500 \
	    -text "$XCeptVersionComment"
    pack $w.headframe.msg1 $w.headframe.msg2 -side top -pady 3 -padx 5

    # ... declare the picture frames (pun intended 8=) ...
    frame $w.topframe.frankframe
    frame $w.topframe.arnoframe
    frame $w.topframe.dirkframe
    pack $w.topframe.arnoframe $w.topframe.frankframe $w.topframe.dirkframe \
	    -side left -padx 5 -pady 5 -expand 1

    # ... Frank Hring ...
    label $w.topframe.frankframe.face \
	    -relief groove -bitmap XCeptBitmapFrank
    message $w.topframe.frankframe.msg -justify center \
	    -font -adobe-helvetica-*-r-*-*-12-*-*-*-*-*-*-* -aspect 500 \
	    -text "Author\nFrank Hring"
    pack $w.topframe.frankframe.face $w.topframe.frankframe.msg -side top

    # ... Arno Augustin ...
    label $w.topframe.arnoframe.face \
	    -relief groove -bitmap XCeptBitmapArno
    message $w.topframe.arnoframe.msg -justify center \
	    -font -adobe-helvetica-*-r-*-*-12-*-*-*-*-*-*-* -aspect 500 \
	    -text "Author\nArno Augustin"
    pack $w.topframe.arnoframe.face $w.topframe.arnoframe.msg -side top

    # ... Dirk Husemann ...
    label $w.topframe.dirkframe.face \
	    -relief groove -bitmap XCeptBitmapDirk
    message $w.topframe.dirkframe.msg -justify center \
	    -font -adobe-helvetica-*-r-*-*-12-*-*-*-*-*-*-* -aspect 500 \
	    -text "Advisor\nDirk Husemann"
    pack $w.topframe.dirkframe.face $w.topframe.dirkframe.msg -side top

    # ... and say "goodbye, yawl" ...
    button $w.botframe.butt -relief raised -text "I'm flabbergasted..." \
	    -padx 3 -command "destroy $w"
    pack $w.botframe.butt -pady 5 -anchor e -side right -padx 15 
}


# ... hmm, going for the juicy stuff, aren't we? ...
proc XCeptExecCode {{w .enterw}} {
    global XCeptSaveFilename

    catch {destroy $w}

    toplevel $w
    wm title $w "XCept TCL Code Scratch Pad"

    set XCeptSaveFilename($w.t) ""

    frame $w.bframe
    button $w.bframe.load -text Load -relief groove -bd 2 \
	    -command "focus .; XCeptTextLoadScript $w.t" 
    button $w.bframe.save -text Save -relief groove -bd 2 \
	    -command "focus .; XCeptTextSaveScript $w.t"
    button $w.bframe.eval -text EVAL -relief groove -bd 2 \
	    -command "focus .; eval \[$w.t get 1.0 end\]"
    button $w.bframe.close -text Close -relief groove -bd 2 \
	    -command "focus .; destroy $w"
    button $w.bframe.clear -text Clear -relief groove -bd 2 \
	    -command "set XCeptSaveFilename($w.t) \"\"; $w.t delete 1.0 end"
    text $w.t -relief sunken -bd 2 -width 65 -height 12 \
	    -yscrollcommand "$w.s set" -setgrid true
    scrollbar $w.s -bd 1 -width 11 -command "$w.t yview"
    
    pack $w.bframe.close $w.bframe.load $w.bframe.save \
	  $w.bframe.clear $w.bframe.eval -side left -fill x -expand 1
    pack $w.bframe -side bottom -fill x
    pack $w.s -side right -fill y
    pack $w.t -side top -expand true -fill both

    bind $w.t <Meta-Return> "eval \[$w.t get 1.0 end\]"
    bind $w.t <Meta-o> "XCeptTextLoadScript $w.t"
    bind $w.t <Meta-l> "XCeptTextLoadScript $w.t" 
    bind $w.t <Meta-s> "XCeptTextSaveScript $w.t"
    bind $w.t <Meta-w> "destroy $w"
    bind $w.t <Meta-c> "set XCeptSaveFilename($w.t) \"\"; $w.t delete 1.0 end"

    bind $w.t <Tab> {
	set short [%W get "insert-1c wordstart" insert]
	set a [string length $short]
	set cmdlist [info commands $short*]
	set cmd0 [lindex $cmdlist 0]
	if [llength $cmdlist] {
	    for {set b $a} {[string index $cmd0 $b]!=""} {incr b} {
		set cmpchar [string index $cmd0 $b]
		set equal 1
		foreach j $cmdlist {
		    if {[string index $j $b] != $cmpchar} {set equal 0; break}
		}
		if !$equal break
	    }
	    if {$b > $a} {
		%W insert insert [string range $cmd0 $a [expr $b - 1]]
		%W yview -pickplace insert
	    }
	}
    }

    bind $w <Leave> "focus ."
    
    focus $w.t
}

proc XCeptTextLoadScript {w} {
    global fsBox XCeptSaveFilename

    #set fsBox(pattern) *.xcept
    #set name [FSBox "Select script to load"]
    set name [tk_getOpenFile -parent . -title "Select script to load"]
    if {$name != ""} {
	set XCeptSaveFilename($w) $name
	set fd [open $name r]
	$w delete 1.0 end
	$w insert 1.0 [read $fd] 
	close $fd
    }
}


proc XCeptTextSaveScript {w} {
    global fsBox XCeptSaveFilename

    #set fsBox(pattern) *.xcept
    #set name [FSBox "Select save filename" $XCeptSaveFilename($w)]
    set name [tk_getSaveFile -parent . -title "Select save filename"]
    if {$name != ""} then {
	set XCeptSaveFilename($w) $name
	set fd [open $name w]
	puts -nonewline $fd [$w get 1.0 end]
	close $fd
    }
}


# ... this is ours, you may use because we have our social week ...
proc XCeptCopyright {{w .copy}} {

    toplevel $w
    wm title $w "XCept Copyright"

    button $w.ok -text OK -relief groove -bd 5 -command "destroy $w"
    text $w.t -relief sunken -bd 2 \
	    -yscrollcommand "$w.s set" -setgrid true \
	    -font -adobe-courier-medium-r-normal--12-*
    scrollbar $w.s -bd 1 -width 11 -command "$w.t yview"
    pack  $w.ok -side bottom -fill x
    pack  $w.s -side right -fill y
    pack  $w.t -side top -expand true -fill both
    $w.t insert 0.0 {
XCept Version 3.0

Copyright (c) 1995 IMMD IV (Operating Systems),
	Universitt Erlangen-Nrnberg, Germany.
Copyright (c) 1994, Department of Computer Science IV (Operating Systems), 
          University of Erlangen-Nrnberg, Germany.
Copyright (c) 1992, 1993 Arno Augustin, Frank Hoering, 
          University of Erlangen-Nrnberg, Germany.
All rights reserved.


Non-commercial, i.e. private and academic, redistribution and use in source
and binary forms, with or without modification, are permitted provided that
the following conditions are met:
1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.
3. All advertising materials mentioning features or use of this software
   must display the following acknowledgement:
	This product includes software developed by the Department of
         Computer Science IV (Operating Systems), University of
	Erlangen-Nrnberg, Germany.
4. Neither the name of the University nor the names of its contributors
   may be used to endorse or promote products derived from this software
   without specific prior written permission.

All other kinds of redistribution and use, especially commercially, are
subject to license agreements, details of which are available on request
(contact: 
                Dipl.-Inf. Dirk Husemann
                Universitt Erlangen-Nrnberg
                IMMD IV
                Martensstrae 1
                D-91058 Erlangen
                
                Email:  husemann@informatik.uni-erlangen.de
                FAX:    +49 9131 858 732).

THIS SOFTWARE IS PROVIDED BY THE AUTHORS ``AS IS'' AND ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
EVENT SHALL THE AUTHORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
}

       $w.t configure -state disabled
}


# ... MAIN Part ...

# ... first, parse options ...
XCeptParseOptions

# ... run interactively from the start on? ...
if {$XCeptWantWindow == 1} {
   XCeptOpenTk
   if {!$XCeptHaveColor} {
       tk colormodel . monochrome
   }
   XCeptOpenCEPTWin $XCeptWantSize $XCeptHaveColor
   XCeptShowWindow
}

# ... is a connection required right away? ...
if {$XCeptWantConnect == 1} {
    XCeptConnect $XCeptHostname $XCeptPortNumber
# ... or are we doing a playback right away? ...
} elseif {$XCeptPlaybackFilename != ""} {
    XCeptStartPlayback $XCeptPlaybackFilename
} else {
# ... neither, make sure we're disconnected 8=) ...
    XCeptDisconnect
}

# ... setup auto_path to point to $XCeptSysDir & $XCeptUsrDir
set auto_path [linsert $auto_path 0 $XCeptSysDir]
set auto_path [linsert $auto_path 0 $XCeptUsrDir]

# ... do we have a system-wide rc file to obey? ...
if {[file readable $XCeptSysDir/system-xceptrc] && \
	$XCeptSourceSystemRessource} {
    source $XCeptSysDir/system-xceptrc
}


# ... now look at the user's .xceptrc file and source it ...
if {[file readable ~/.xceptrc] && $XCeptSourceUserRessource} {
    source ~/.xceptrc
}

# ... do we have to execute a script? ...
#     (scripts must use $XCeptScriptParList for obtaining
#     their parameters)
if {$XCeptScriptFilename!=""} {
    source "$XCeptScriptFilename"
}

#EOF
